@@ -316,12 +316,12 @@ int shim_klogctl(int type, char *bufp, int len)
  *  shim_membarrier()
  *	wrapper for membarrier(2) - issue memory barriers
  */
-int shim_membarrier(int cmd, int flags)
+int shim_membarrier(int cmd, int flags, int cpu_id)
 {
 #if defined(__NR_membarrier)
-	return (int)syscall(__NR_membarrier, cmd, flags);
+	return (int)syscall(__NR_membarrier, cmd, flags, cpu_id);
 #else
-	return (int)shim_enosys(0, cmd, flags);
+	return (int)shim_enosys(0, cmd, flags, cpu_id);
 #endif
 }
 
@@ -954,10 +954,14 @@ int shim_brk(void *addr)
 {
 #if defined(__APPLE__)
 	return (int)brk(addr);
+#elif defined(__NR_brk)
+	int ret;
+
+	ret = syscall(__NR_brk, addr);
+	(void)ret;
+	return (errno == 0) ? 0 : ENOMEM;
 #elif defined(HAVE_BRK)
 	return brk(addr);
-#elif defined(__NR_brk)
-	return (int)syscall(__NR_brk, addr);
 #else
 	uintptr_t brkaddr;
 	intptr_t inc;
@@ -1124,7 +1128,9 @@ int shim_fdatasync(int fd)
  */
 int shim_pkey_alloc(unsigned long flags, unsigned long access_rights)
 {
-#if defined(__NR_pkey_alloc)
+#if defined(HAVE_PKEY_ALLOC)
+	return pkey_alloc(flags, access_rights);
+#elif defined(__NR_pkey_alloc)
 	return (int)syscall(__NR_pkey_alloc, flags, access_rights);
 #else
 	return (int)shim_enosys(0, flags, access_rights);
@@ -1137,7 +1143,9 @@ int shim_pkey_alloc(unsigned long flags, unsigned long access_rights)
  */
 int shim_pkey_free(int pkey)
 {
-#if defined(__NR_pkey_free)
+#if defined(HAVE_PKEY_FREE)
+	return pkey_free(pkey);
+#elif defined(__NR_pkey_free)
 	return (int)syscall(__NR_pkey_free, pkey);
 #else
 	return (int)shim_enosys(0, pkey);
@@ -1150,7 +1158,9 @@ int shim_pkey_free(int pkey)
  */
 int shim_pkey_mprotect(void *addr, size_t len, int prot, int pkey)
 {
-#if defined(__NR_pkey_mprotect)
+#if defined(HAVE_PKEY_MPROTECT)
+	return pkey_mprotect(addr, len, prot, pkey);
+#elif defined(__NR_pkey_mprotect)
 	return (int)syscall(__NR_pkey_mprotect, addr, len, prot, pkey);
 #else
 	return (int)shim_enosys(0, addr, len, prot, pkey);
@@ -1163,7 +1173,9 @@ int shim_pkey_mprotect(void *addr, size_t len, int prot, int pkey)
  */
 int shim_pkey_get(int pkey)
 {
-#if defined(__NR_pkey_get)
+#if defined(HAVE_PKEY_GET)
+	return pkey_get(pkey);
+#elif defined(__NR_pkey_get)
 	return (int)syscall(__NR_pkey_get, pkey);
 #else
 	return (int)shim_enosys(0, pkey);
@@ -1176,7 +1188,9 @@ int shim_pkey_get(int pkey)
  */
 int shim_pkey_set(int pkey, unsigned int rights)
 {
-#if defined(__NR_pkey_set)
+#if defined(HAVE_PKEY_SET)
+	return pkey_set(pkey, rights);
+#elif defined(__NR_pkey_set)
 	return (int)syscall(__NR_pkey_set, pkey, rights);
 #else
 	return (int)shim_enosys(0, pkey, rights);
@@ -1222,12 +1236,12 @@ pid_t shim_waitpid(pid_t pid, int *wstatus, int options)
 		 *  consecutive EINTRs then give up.
 		 */
 		if (!keep_stressing_flag()) {
-			kill(pid, SIGALRM);
+			(void)kill(pid, SIGALRM);
 			if (count > 120)
-				kill(pid, SIGKILL);
+				(void)kill(pid, SIGKILL);
 		}
 		if (count > 10)
-			sleep(1);
+			(void)sleep(1);
 	}
 	return ret;
 }
@@ -2005,3 +2019,17 @@ int shim_modify_ldt(int func, void *ptr, unsigned long bytecount)
 	return (int)shim_enosys(0, func, ptr, bytecount);
 #endif
 }
+
+/*
+ *  shim_process_mrelease()
+ *	system call wrapper for Linux 5.14 process_mrelease
+ */
+int shim_process_mrelease(int pidfd, unsigned int flags)
+{
+#if defined(__NR_process_release)
+	return (int)syscall(__NR_process_release, pidfd, flags);
+#else
+	return (int)shim_enosys(0, pidfd, flags);
+#endif
+}
+
