@@ -217,8 +217,7 @@ static pid_t apparmor_spawn(
 again:
 	pid = fork();
 	if (pid < 0) {
-		if (keep_stressing_flag() &&
-		    ((errno == EAGAIN) || (errno == ENOMEM)))
+		if (stress_redo_fork(errno))
 			goto again;
 		return -1;
 	}
@@ -241,7 +240,7 @@ again:
 		ret = func(args->name, max_ops, counter);
 abort:
 		free(apparmor_path);
-		kill(args->pid, SIGUSR1);
+		(void)kill(args->pid, SIGUSR1);
 		_exit(ret);
 	}
 	(void)setpgid(pid, g_pgrp);
