@@ -3421,8 +3421,10 @@ again:
 		return EXIT_SUCCESS;
 	pid = fork();
 	if (pid < 0) {
-		if ((errno == EAGAIN) || (errno == ENOMEM))
+		if (stress_redo_fork(errno))
 			goto again;
+		if (!keep_stressing(args))
+			goto deinit;
 		pr_err("%s: fork failed: errno=%d: (%s)\n",
 			args->name, errno, strerror(errno));
 	} else if (pid > 0) {
@@ -3538,6 +3540,7 @@ finish:
 		syscall_free();
 		_exit(EXIT_SUCCESS);
 	}
+deinit:
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
 	return EXIT_SUCCESS;
