@@ -87,7 +87,7 @@ static void stress_fifo_reader(
 	const char *name,
 	const char *fifoname)
 {
-	int fd;
+	int fd, count = 0;
 	uint64_t val, lastval = 0;
 
 	fd = open(fifoname, O_RDONLY | O_NONBLOCK);
@@ -125,6 +125,14 @@ redo:
 				goto redo;
 			break;
 		}
+#if defined(FIONREAD)
+		if ((count & 0xff) == 0) {
+			int isz = 0;
+
+			ret = ioctl(fd, FIONREAD, &isz);
+			(void)ret;
+		}
+#endif
 		sz = read(fd, &val, sizeof(val));
 		if (sz < 0) {
 			if ((errno == EAGAIN) || (errno == EINTR))
@@ -147,6 +155,22 @@ redo:
 			break;
 		}
 		lastval = val;
+
+		if ((count & 0x1ff) == 0) {
+			off_t off;
+			void *ptr;
+
+			/* Exercise lseek -> ESPIPE */
+			off = lseek(fd, 0, SEEK_CUR);
+			(void)off;
+
+			/* Exercise mmap -> ENODEV */
+			ptr = mmap(NULL, args->page_size, PROT_READ,
+				MAP_PRIVATE, fd, 0);
+			if (ptr)
+				(void)munmap(ptr, args->page_size);
+		}
+		count++;
 	}
 	(void)close(fd);
 }
