@@ -405,8 +405,12 @@ again:
 	}
 	pid = fork();
 	if (pid < 0) {
-		if ((errno == EAGAIN) || (errno == ENOMEM))
+		if (stress_redo_fork(errno))
 			goto again;
+		if (!keep_stressing(args)) {
+			rc = EXIT_SUCCESS;
+			goto tidy_dir;
+		}
 		pr_err("%s: fork failed: errno=%d: (%s)\n",
 			args->name, errno, strerror(errno));
 	} else if (pid > 0) {
