@@ -40,6 +40,7 @@ static const stress_help_t help[] = {
 	{ NULL,	NULL,			NULL }
 };
 
+#define bool_put	stress_uint8_put
 #define uint8_t_put	stress_uint8_put
 #define uint16_t_put	stress_uint16_put
 #define uint32_t_put	stress_uint32_put
@@ -48,8 +49,92 @@ static const stress_help_t help[] = {
 #define float_put	stress_float_put
 #define double_put	stress_double_put
 #define stress_long_double_t_put stress_long_double_put
+typedef long double 		stress_long_double_t;
+#if defined(HAVE_COMPLEX_H) &&			\
+    defined(HAVE_COMPLEX) &&			\
+    defined(__STDC_IEC_559_COMPLEX__) &&	\
+    !defined(__UCLIBC__)
+#define stress_complex_float_t_put stress_complex_put
+#define stress_complex_double_t_put stress_complex_put
+#define stress_complex_long_double_t_put stress_complex_put
+typedef complex float		stress_complex_float_t;
+typedef complex double		stress_complex_double_t;
+typedef complex long double	stress_complex_long_double_t;
+#endif
 
-typedef long double 	stress_long_double_t;
+static inline float stress_mwcfloat(void)
+{
+	const uint32_t r = stress_mwc32();
+
+	return (float)r / (float)(0xffffffffUL);
+}
+
+static inline double stress_mwcdouble(void)
+{
+	const uint64_t r = stress_mwc64();
+
+	return (double)r / (double)(0xffffffffffffffffULL);
+}
+
+#define stress_funccall_type(type, rndfunc)				\
+static void NOINLINE stress_funccall_ ## type(const stress_args_t *args);	\
+									\
+static void NOINLINE stress_funccall_ ## type(const stress_args_t *args)	\
+{									\
+	register int ii;						\
+	type a, b, c, d, e, f, g, h, i;					\
+									\
+	a = rndfunc();							\
+	b = rndfunc();							\
+	c = rndfunc();							\
+	d = rndfunc();							\
+	e = rndfunc();							\
+	f = rndfunc();							\
+	g = rndfunc();							\
+	h = rndfunc();							\
+	i = rndfunc();							\
+									\
+	do {								\
+		for (ii = 0; ii < 1000; ii++) {				\
+			type res = 					\
+			(stress_funccall_ ## type ## _1(a) + 		\
+			 stress_funccall_ ## type ## _2(a, b) +		\
+			 stress_funccall_ ## type ## _3(a, b,		\
+				c) +					\
+			 stress_funccall_ ## type ## _4(a, b, 		\
+				c, d) + 				\
+			 stress_funccall_ ## type ## _5(a, b,		\
+				c, d, e) +				\
+			 stress_funccall_ ## type ## _6(a, b,		\
+				c, d, e, f) + 				\
+			 stress_funccall_ ## type ## _7(a, b,		\
+				c, d, e, f, g) + 			\
+			 stress_funccall_ ## type ## _8(a, b,		\
+				c, d, e, f, g, h) + 			\
+			 stress_funccall_ ## type ## _9(a, b,		\
+				c, d, e, f, g, h, i));			\
+									\
+			res += 						\
+			(stress_funcdeep_ ## type ## _2(a, b) +		\
+			 stress_funcdeep_ ## type ## _3(a, b,		\
+				c) + 					\
+			 stress_funcdeep_ ## type ## _4(a, b, 		\
+				c, d) +					\
+			 stress_funcdeep_ ## type ## _5(a, b,		\
+				c, d, e) +				\
+			 stress_funcdeep_ ## type ## _6(a, b,		\
+				c, d, e, f) +				\
+			 stress_funcdeep_ ## type ## _7(a, b,		\
+				c, d, e, f, g) +			\
+			 stress_funcdeep_ ## type ## _8(a, b,		\
+				c, d, e, f, g, h) +			\
+			 stress_funcdeep_ ## type ## _9(a, b,		\
+				c, d, e, f, g, h, i));			\
+			type ## _put(res);				\
+			}						\
+		inc_counter(args);					\
+	} while (keep_stressing(args));					\
+}
 
 #define stress_funccall_1(type)				\
 static type NOINLINE stress_funccall_ ## type ## _1(	\
@@ -440,6 +525,25 @@ static type NOINLINE stress_funcdeep_ ## type ## _9(	\
 	stress_funccall_ ## type ## _1(h);		\
 }							\
 
+stress_funccall_1(bool)
+stress_funccall_2(bool)
+stress_funccall_3(bool)
+stress_funccall_4(bool)
+stress_funccall_5(bool)
+stress_funccall_6(bool)
+stress_funccall_7(bool)
+stress_funccall_8(bool)
+stress_funccall_9(bool)
+stress_funcdeep_2(bool)
+stress_funcdeep_3(bool)
+stress_funcdeep_4(bool)
+stress_funcdeep_5(bool)
+stress_funcdeep_6(bool)
+stress_funcdeep_7(bool)
+stress_funcdeep_8(bool)
+stress_funcdeep_9(bool)
+stress_funccall_type(bool, stress_mwc1)
+
 stress_funccall_1(uint8_t)
 stress_funccall_2(uint8_t)
 stress_funccall_3(uint8_t)
@@ -449,7 +553,6 @@ stress_funccall_6(uint8_t)
 stress_funccall_7(uint8_t)
 stress_funccall_8(uint8_t)
 stress_funccall_9(uint8_t)
-
 stress_funcdeep_2(uint8_t)
 stress_funcdeep_3(uint8_t)
 stress_funcdeep_4(uint8_t)
@@ -458,6 +561,7 @@ stress_funcdeep_6(uint8_t)
 stress_funcdeep_7(uint8_t)
 stress_funcdeep_8(uint8_t)
 stress_funcdeep_9(uint8_t)
+stress_funccall_type(uint8_t, stress_mwc8)
 
 stress_funccall_1(uint16_t)
 stress_funccall_2(uint16_t)
@@ -468,7 +572,6 @@ stress_funccall_6(uint16_t)
 stress_funccall_7(uint16_t)
 stress_funccall_8(uint16_t)
 stress_funccall_9(uint16_t)
-
 stress_funcdeep_2(uint16_t)
 stress_funcdeep_3(uint16_t)
 stress_funcdeep_4(uint16_t)
@@ -477,6 +580,7 @@ stress_funcdeep_6(uint16_t)
 stress_funcdeep_7(uint16_t)
 stress_funcdeep_8(uint16_t)
 stress_funcdeep_9(uint16_t)
+stress_funccall_type(uint16_t, stress_mwc16)
 
 stress_funccall_1(uint32_t)
 stress_funccall_2(uint32_t)
@@ -487,7 +591,6 @@ stress_funccall_6(uint32_t)
 stress_funccall_7(uint32_t)
 stress_funccall_8(uint32_t)
 stress_funccall_9(uint32_t)
-
 stress_funcdeep_2(uint32_t)
 stress_funcdeep_3(uint32_t)
 stress_funcdeep_4(uint32_t)
@@ -496,6 +599,7 @@ stress_funcdeep_6(uint32_t)
 stress_funcdeep_7(uint32_t)
 stress_funcdeep_8(uint32_t)
 stress_funcdeep_9(uint32_t)
+stress_funccall_type(uint32_t, stress_mwc32)
 
 stress_funccall_1(uint64_t)
 stress_funccall_2(uint64_t)
@@ -506,7 +610,6 @@ stress_funccall_6(uint64_t)
 stress_funccall_7(uint64_t)
 stress_funccall_8(uint64_t)
 stress_funccall_9(uint64_t)
-
 stress_funcdeep_2(uint64_t)
 stress_funcdeep_3(uint64_t)
 stress_funcdeep_4(uint64_t)
@@ -515,6 +618,7 @@ stress_funcdeep_6(uint64_t)
 stress_funcdeep_7(uint64_t)
 stress_funcdeep_8(uint64_t)
 stress_funcdeep_9(uint64_t)
+stress_funccall_type(uint64_t, stress_mwc64)
 
 #if defined(HAVE_INT128_T)
 stress_funccall_1(__uint128_t)
@@ -526,7 +630,6 @@ stress_funccall_6(__uint128_t)
 stress_funccall_7(__uint128_t)
 stress_funccall_8(__uint128_t)
 stress_funccall_9(__uint128_t)
-
 stress_funcdeep_2(__uint128_t)
 stress_funcdeep_3(__uint128_t)
 stress_funcdeep_4(__uint128_t)
@@ -535,6 +638,7 @@ stress_funcdeep_6(__uint128_t)
 stress_funcdeep_7(__uint128_t)
 stress_funcdeep_8(__uint128_t)
 stress_funcdeep_9(__uint128_t)
+stress_funccall_type(__uint128_t, stress_mwc64)
 #endif
 
 stress_funccall_1(float)
@@ -546,7 +650,6 @@ stress_funccall_6(float)
 stress_funccall_7(float)
 stress_funccall_8(float)
 stress_funccall_9(float)
-
 stress_funcdeep_2(float)
 stress_funcdeep_3(float)
 stress_funcdeep_4(float)
@@ -555,6 +658,7 @@ stress_funcdeep_6(float)
 stress_funcdeep_7(float)
 stress_funcdeep_8(float)
 stress_funcdeep_9(float)
+stress_funccall_type(float, stress_mwcfloat)
 
 stress_funccall_1(double)
 stress_funccall_2(double)
@@ -565,7 +669,6 @@ stress_funccall_6(double)
 stress_funccall_7(double)
 stress_funccall_8(double)
 stress_funccall_9(double)
-
 stress_funcdeep_2(double)
 stress_funcdeep_3(double)
 stress_funcdeep_4(double)
@@ -574,6 +677,7 @@ stress_funcdeep_6(double)
 stress_funcdeep_7(double)
 stress_funcdeep_8(double)
 stress_funcdeep_9(double)
+stress_funccall_type(double, stress_mwcdouble)
 
 stress_funccall_1(stress_long_double_t)
 stress_funccall_2(stress_long_double_t)
@@ -584,7 +688,6 @@ stress_funccall_6(stress_long_double_t)
 stress_funccall_7(stress_long_double_t)
 stress_funccall_8(stress_long_double_t)
 stress_funccall_9(stress_long_double_t)
-
 stress_funcdeep_2(stress_long_double_t)
 stress_funcdeep_3(stress_long_double_t)
 stress_funcdeep_4(stress_long_double_t)
@@ -593,6 +696,79 @@ stress_funcdeep_6(stress_long_double_t)
 stress_funcdeep_7(stress_long_double_t)
 stress_funcdeep_8(stress_long_double_t)
 stress_funcdeep_9(stress_long_double_t)
+stress_funccall_type(stress_long_double_t, stress_mwc64)
+
+#if defined(HAVE_COMPLEX_H) &&			\
+    defined(HAVE_COMPLEX) &&			\
+    defined(__STDC_IEC_559_COMPLEX__) &&	\
+    !defined(__UCLIBC__)
+static inline void ALWAYS_INLINE stress_complex_put(const complex double a)
+{
+#if defined(HAVE_CREAL) &&	\
+    defined(HAVE_CIMAG)
+	g_put_val.double_val = creal(a) * cimag(a);
+#else
+	g_put_val.double_val = a * a;
+#endif
+}
+
+stress_funccall_1(stress_complex_float_t)
+stress_funccall_2(stress_complex_float_t)
+stress_funccall_3(stress_complex_float_t)
+stress_funccall_4(stress_complex_float_t)
+stress_funccall_5(stress_complex_float_t)
+stress_funccall_6(stress_complex_float_t)
+stress_funccall_7(stress_complex_float_t)
+stress_funccall_8(stress_complex_float_t)
+stress_funccall_9(stress_complex_float_t)
+stress_funcdeep_2(stress_complex_float_t)
+stress_funcdeep_3(stress_complex_float_t)
+stress_funcdeep_4(stress_complex_float_t)
+stress_funcdeep_5(stress_complex_float_t)
+stress_funcdeep_6(stress_complex_float_t)
+stress_funcdeep_7(stress_complex_float_t)
+stress_funcdeep_8(stress_complex_float_t)
+stress_funcdeep_9(stress_complex_float_t)
+stress_funccall_type(stress_complex_float_t, stress_mwcdouble)
+
+stress_funccall_1(stress_complex_double_t)
+stress_funccall_2(stress_complex_double_t)
+stress_funccall_3(stress_complex_double_t)
+stress_funccall_4(stress_complex_double_t)
+stress_funccall_5(stress_complex_double_t)
+stress_funccall_6(stress_complex_double_t)
+stress_funccall_7(stress_complex_double_t)
+stress_funccall_8(stress_complex_double_t)
+stress_funccall_9(stress_complex_double_t)
+stress_funcdeep_2(stress_complex_double_t)
+stress_funcdeep_3(stress_complex_double_t)
+stress_funcdeep_4(stress_complex_double_t)
+stress_funcdeep_5(stress_complex_double_t)
+stress_funcdeep_6(stress_complex_double_t)
+stress_funcdeep_7(stress_complex_double_t)
+stress_funcdeep_8(stress_complex_double_t)
+stress_funcdeep_9(stress_complex_double_t)
+stress_funccall_type(stress_complex_double_t, stress_mwcdouble)
+
+stress_funccall_1(stress_complex_long_double_t)
+stress_funccall_2(stress_complex_long_double_t)
+stress_funccall_3(stress_complex_long_double_t)
+stress_funccall_4(stress_complex_long_double_t)
+stress_funccall_5(stress_complex_long_double_t)
+stress_funccall_6(stress_complex_long_double_t)
+stress_funccall_7(stress_complex_long_double_t)
+stress_funccall_8(stress_complex_long_double_t)
+stress_funccall_9(stress_complex_long_double_t)
+stress_funcdeep_2(stress_complex_long_double_t)
+stress_funcdeep_3(stress_complex_long_double_t)
+stress_funcdeep_4(stress_complex_long_double_t)
+stress_funcdeep_5(stress_complex_long_double_t)
+stress_funcdeep_6(stress_complex_long_double_t)
+stress_funcdeep_7(stress_complex_long_double_t)
+stress_funcdeep_8(stress_complex_long_double_t)
+stress_funcdeep_9(stress_complex_long_double_t)
+stress_funccall_type(stress_complex_long_double_t, stress_mwcdouble)
+#endif
 
 /*
  *  The PCC compiler complains at ALWAYS_INLINE, so disable it
@@ -618,7 +794,6 @@ stress_funccall_6(_Decimal32)
 stress_funccall_7(_Decimal32)
 stress_funccall_8(_Decimal32)
 stress_funccall_9(_Decimal32)
-
 stress_funcdeep_2(_Decimal32)
 stress_funcdeep_3(_Decimal32)
 stress_funcdeep_4(_Decimal32)
@@ -627,6 +802,7 @@ stress_funcdeep_6(_Decimal32)
 stress_funcdeep_7(_Decimal32)
 stress_funcdeep_8(_Decimal32)
 stress_funcdeep_9(_Decimal32)
+stress_funccall_type(_Decimal32, (_Decimal32)stress_mwc64)
 #endif
 
 #if defined(HAVE_FLOAT_DECIMAL64) &&	\
@@ -645,7 +821,6 @@ stress_funccall_6(_Decimal64)
 stress_funccall_7(_Decimal64)
 stress_funccall_8(_Decimal64)
 stress_funccall_9(_Decimal64)
-
 stress_funcdeep_2(_Decimal64)
 stress_funcdeep_3(_Decimal64)
 stress_funcdeep_4(_Decimal64)
@@ -654,6 +829,7 @@ stress_funcdeep_6(_Decimal64)
 stress_funcdeep_7(_Decimal64)
 stress_funcdeep_8(_Decimal64)
 stress_funcdeep_9(_Decimal64)
+stress_funccall_type(_Decimal64, (_Decimal64)stress_mwc64)
 #endif
 
 #if defined(HAVE_FLOAT_DECIMAL128) &&	\
@@ -672,7 +848,6 @@ stress_funccall_6(_Decimal128)
 stress_funccall_7(_Decimal128)
 stress_funccall_8(_Decimal128)
 stress_funccall_9(_Decimal128)
-
 stress_funcdeep_2(_Decimal128)
 stress_funcdeep_3(_Decimal128)
 stress_funcdeep_4(_Decimal128)
@@ -681,8 +856,91 @@ stress_funcdeep_6(_Decimal128)
 stress_funcdeep_7(_Decimal128)
 stress_funcdeep_8(_Decimal128)
 stress_funcdeep_9(_Decimal128)
+stress_funccall_type(_Decimal128, (_Decimal128)stress_mwc64)
 #endif
 
+#if defined(HAVE_FLOAT16) &&	\
+    !defined(__clang__)
+static inline void ALWAYS_INLINE __fp16_put(const __fp16 a)
+{
+	g_put_val.float_val = (float)a;
+}
+
+stress_funccall_1(__fp16)
+stress_funccall_2(__fp16)
+stress_funccall_3(__fp16)
+stress_funccall_4(__fp16)
+stress_funccall_5(__fp16)
+stress_funccall_6(__fp16)
+stress_funccall_7(__fp16)
+stress_funccall_8(__fp16)
+stress_funccall_9(__fp16)
+stress_funcdeep_2(__fp16)
+stress_funcdeep_3(__fp16)
+stress_funcdeep_4(__fp16)
+stress_funcdeep_5(__fp16)
+stress_funcdeep_6(__fp16)
+stress_funcdeep_7(__fp16)
+stress_funcdeep_8(__fp16)
+stress_funcdeep_9(__fp16)
+stress_funccall_type(__fp16, (__fp16)stress_mwc32)
+#endif
+
+#if defined(HAVE_FLOAT32) &&	\
+    !defined(__clang__)
+static inline void ALWAYS_INLINE _Float32_put(const _Float32 a)
+{
+	g_put_val.float_val = (float)a;
+}
+
+stress_funccall_1(_Float32)
+stress_funccall_2(_Float32)
+stress_funccall_3(_Float32)
+stress_funccall_4(_Float32)
+stress_funccall_5(_Float32)
+stress_funccall_6(_Float32)
+stress_funccall_7(_Float32)
+stress_funccall_8(_Float32)
+stress_funccall_9(_Float32)
+stress_funcdeep_2(_Float32)
+stress_funcdeep_3(_Float32)
+stress_funcdeep_4(_Float32)
+stress_funcdeep_5(_Float32)
+stress_funcdeep_6(_Float32)
+stress_funcdeep_7(_Float32)
+stress_funcdeep_8(_Float32)
+stress_funcdeep_9(_Float32)
+stress_funccall_type(_Float32, (_Float32)stress_mwc32)
+#endif
+
+#if defined(HAVE_FLOAT64) &&	\
+    !defined(__clang__)
+static inline void ALWAYS_INLINE _Float64_put(const _Float64 a)
+{
+	g_put_val.double_val = (double)a;
+}
+
+stress_funccall_1(_Float64)
+stress_funccall_2(_Float64)
+stress_funccall_3(_Float64)
+stress_funccall_4(_Float64)
+stress_funccall_5(_Float64)
+stress_funccall_6(_Float64)
+stress_funccall_7(_Float64)
+stress_funccall_8(_Float64)
+stress_funccall_9(_Float64)
+stress_funcdeep_2(_Float64)
+stress_funcdeep_3(_Float64)
+stress_funcdeep_4(_Float64)
+stress_funcdeep_5(_Float64)
+stress_funcdeep_6(_Float64)
+stress_funcdeep_7(_Float64)
+stress_funcdeep_8(_Float64)
+stress_funcdeep_9(_Float64)
+stress_funccall_type(_Float64, (_Float64)stress_mwc64)
+#endif
+
+
 #if defined(HAVE_FLOAT80) &&	\
     !defined(__clang__)
 static inline void ALWAYS_INLINE __float80_put(const __float80 a)
@@ -699,7 +957,6 @@ stress_funccall_6(__float80)
 stress_funccall_7(__float80)
 stress_funccall_8(__float80)
 stress_funccall_9(__float80)
-
 stress_funcdeep_2(__float80)
 stress_funcdeep_3(__float80)
 stress_funcdeep_4(__float80)
@@ -708,6 +965,7 @@ stress_funcdeep_6(__float80)
 stress_funcdeep_7(__float80)
 stress_funcdeep_8(__float80)
 stress_funcdeep_9(__float80)
+stress_funccall_type(__float80, (__float80)stress_mwc64)
 #endif
 
 #if defined(HAVE_FLOAT128) &&	\
@@ -726,7 +984,6 @@ stress_funccall_6(__float128)
 stress_funccall_7(__float128)
 stress_funccall_8(__float128)
 stress_funccall_9(__float128)
-
 stress_funcdeep_2(__float128)
 stress_funcdeep_3(__float128)
 stress_funcdeep_4(__float128)
@@ -735,110 +992,6 @@ stress_funcdeep_6(__float128)
 stress_funcdeep_7(__float128)
 stress_funcdeep_8(__float128)
 stress_funcdeep_9(__float128)
-#endif
-
-static inline float stress_mwcfloat(void)
-{
-	const uint32_t r = stress_mwc32();
-
-	return (float)r / (float)(0xffffffffUL);
-}
-
-static inline double stress_mwcdouble(void)
-{
-	const uint64_t r = stress_mwc64();
-
-	return (double)r / (double)(0xffffffffffffffffULL);
-}
-
-#define stress_funccall_type(type, rndfunc)				\
-static void NOINLINE stress_funccall_ ## type(const stress_args_t *args);	\
-									\
-static void NOINLINE stress_funccall_ ## type(const stress_args_t *args)	\
-{									\
-	register int ii;						\
-	type a, b, c, d, e, f, g, h, i;					\
-									\
-	a = rndfunc();							\
-	b = rndfunc();							\
-	c = rndfunc();							\
-	d = rndfunc();							\
-	e = rndfunc();							\
-	f = rndfunc();							\
-	g = rndfunc();							\
-	h = rndfunc();							\
-	i = rndfunc();							\
-									\
-	do {								\
-		for (ii = 0; ii < 1000; ii++) {				\
-			type res = 					\
-			(stress_funccall_ ## type ## _1(a) + 		\
-			 stress_funccall_ ## type ## _2(a, b) +		\
-			 stress_funccall_ ## type ## _3(a, b,		\
-				c) +					\
-			 stress_funccall_ ## type ## _4(a, b, 		\
-				c, d) + 				\
-			 stress_funccall_ ## type ## _5(a, b,		\
-				c, d, e) +				\
-			 stress_funccall_ ## type ## _6(a, b,		\
-				c, d, e, f) + 				\
-			 stress_funccall_ ## type ## _7(a, b,		\
-				c, d, e, f, g) + 			\
-			 stress_funccall_ ## type ## _8(a, b,		\
-				c, d, e, f, g, h) + 			\
-			 stress_funccall_ ## type ## _9(a, b,		\
-				c, d, e, f, g, h, i));			\
-									\
-			res += 						\
-			(stress_funcdeep_ ## type ## _2(a, b) +		\
-			 stress_funcdeep_ ## type ## _3(a, b,		\
-				c) + 					\
-			 stress_funcdeep_ ## type ## _4(a, b, 		\
-				c, d) +					\
-			 stress_funcdeep_ ## type ## _5(a, b,		\
-				c, d, e) +				\
-			 stress_funcdeep_ ## type ## _6(a, b,		\
-				c, d, e, f) +				\
-			 stress_funcdeep_ ## type ## _7(a, b,		\
-				c, d, e, f, g) +			\
-			 stress_funcdeep_ ## type ## _8(a, b,		\
-				c, d, e, f, g, h) +			\
-			 stress_funcdeep_ ## type ## _9(a, b,		\
-				c, d, e, f, g, h, i));			\
-			type ## _put(res);				\
-			}						\
-		inc_counter(args);					\
-	} while (keep_stressing(args));					\
-}
-
-stress_funccall_type(uint8_t, stress_mwc8)
-stress_funccall_type(uint16_t, stress_mwc16)
-stress_funccall_type(uint32_t, stress_mwc32)
-stress_funccall_type(uint64_t, stress_mwc64)
-#if defined(HAVE_INT128_T)
-stress_funccall_type(__uint128_t, stress_mwc64)
-#endif
-stress_funccall_type(float, stress_mwcfloat)
-stress_funccall_type(double, stress_mwcdouble)
-stress_funccall_type(stress_long_double_t, stress_mwc64)
-#if defined(HAVE_FLOAT_DECIMAL32) &&	\
-    !defined(__clang__)
-stress_funccall_type(_Decimal32, (_Decimal32)stress_mwc64)
-#endif
-#if defined(HAVE_FLOAT_DECIMAL64) &&	\
-    !defined(__clang__)
-stress_funccall_type(_Decimal64, (_Decimal64)stress_mwc64)
-#endif
-#if defined(HAVE_FLOAT_DECIMAL128) &&	\
-    !defined(__clang__)
-stress_funccall_type(_Decimal128, (_Decimal128)stress_mwc64)
-#endif
-#if defined(HAVE_FLOAT80) &&		\
-    !defined(__clang__)
-stress_funccall_type(__float80, (__float80)stress_mwc64)
-#endif
-#if defined(HAVE_FLOAT128) &&		\
-    !defined(__clang__)
 stress_funccall_type(__float128, (__float128)stress_mwc64)
 #endif
 
@@ -846,6 +999,7 @@ stress_funccall_type(__float128, (__float128)stress_mwc64)
  * Table of func call stress methods
  */
 static const stress_funccall_method_info_t funccall_methods[] = {
+	{ "bool",	stress_funccall_bool },
 	{ "uint8",	stress_funccall_uint8_t },
 	{ "uint16",	stress_funccall_uint16_t },
 	{ "uint32",	stress_funccall_uint32_t },
@@ -854,8 +1008,18 @@ static const stress_funccall_method_info_t funccall_methods[] = {
 	{ "uint128",	stress_funccall___uint128_t },
 #endif
 	{ "float",	stress_funccall_float },
-	{ "double",	stress_funccall_double },
-	{ "longdouble",	stress_funccall_stress_long_double_t },
+#if defined(HAVE_FLOAT16) &&	\
+    !defined(__clang__)
+	{ "float16",	stress_funccall___fp16 },
+#endif
+#if defined(HAVE_FLOAT32) &&	\
+    !defined(__clang__)
+	{ "float32",	stress_funccall__Float32 },
+#endif
+#if defined(HAVE_FLOAT64) &&	\
+    !defined(__clang__)
+	{ "float64",	stress_funccall__Float64 },
+#endif
 #if defined(HAVE_FLOAT80) &&	\
     !defined(__clang__)
 	{ "float80",	stress_funccall___float80 },
@@ -863,6 +1027,16 @@ static const stress_funccall_method_info_t funccall_methods[] = {
 #if defined(HAVE_FLOAT128) &&	\
     !defined(__clang__)
 	{ "float128",	stress_funccall___float128 },
+#endif
+	{ "double",	stress_funccall_double },
+	{ "longdouble",	stress_funccall_stress_long_double_t },
+#if defined(HAVE_COMPLEX_H) &&			\
+    defined(HAVE_COMPLEX) &&			\
+    defined(__STDC_IEC_559_COMPLEX__) &&	\
+    !defined(__UCLIBC__)
+	{ "cfloat",	stress_funccall_stress_complex_float_t },
+	{ "cdouble",	stress_funccall_stress_complex_double_t },
+	{ "clongdouble",stress_funccall_stress_complex_long_double_t },
 #endif
 #if defined(HAVE_FLOAT_DECIMAL32) &&	\
     !defined(__clang__)
