@@ -184,13 +184,13 @@ static int stress_kcmp(const stress_args_t *args)
 again:
 	pid1 = fork();
 	if (pid1 < 0) {
-		if (keep_stressing_flag() &&
-		    ((errno == EAGAIN) || (errno == ENOMEM)))
+		if (stress_redo_fork(errno))
 			goto again;
-
+		(void)close(fd1);
+		if (!keep_stressing(args))
+			goto finish;
 		pr_fail("%s: fork failed, errno=%d (%s)\n",
 			args->name, errno, strerror(errno));
-		(void)close(fd1);
 #if defined(HAVE_SYS_EPOLL_H) &&	\
     NEED_GLIBC(2,3,2)
 		if (sfd != -1)
@@ -301,6 +301,8 @@ again:
 			 */
 			(void)SHIM_KCMP(pid1, pid2, 0x7fffffff, 0, 0);
 			(void)SHIM_KCMP(pid1, pid2, SHIM_KCMP_FILE, bad_fd, fd1);
+			(void)SHIM_KCMP(pid1, INT_MAX, SHIM_KCMP_FILE, fd1, fd2);
+			(void)SHIM_KCMP(INT_MAX, pid2, SHIM_KCMP_FILE, fd1, fd2);
 			if (!is_root)
 				(void)SHIM_KCMP(1, pid2, SHIM_KCMP_SIGHAND, 0, 0);
 
@@ -313,6 +315,7 @@ reap:
 		(void)shim_waitpid(pid1, &status, 0);
 		(void)close(fd1);
 	}
+finish:
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
 #if defined(HAVE_SYS_EPOLL_H) &&	\
