@@ -129,9 +129,11 @@ static void stress_malloc_page_touch(
 	const size_t size,
 	const size_t page_size)
 {
-	uint8_t *ptr = buffer, *end = buffer + size;
 
 	if (malloc_touch) {
+		register uint8_t *ptr;
+		const uint8_t *end = buffer + size;
+
 		for (ptr = buffer; ptr < end; ptr += page_size)
 			*ptr = 0xff;
 	} else {
@@ -145,7 +147,7 @@ static void stress_malloc_page_touch(
  *	if we lock the args->counter, so sum per-process
  *	counters in a racy way.
  */
-static uint64_t stress_malloc_racy_count(uint64_t *counters)
+static uint64_t stress_malloc_racy_count(const uint64_t *counters)
 {
 	register uint64_t count = 0;
 	register size_t i;
