@@ -61,6 +61,7 @@ static inline bool stress_syscall_wait(
 			return false;
 		if (WIFEXITED(status))
 			return true;
+
 	}
 	return true;
 }
@@ -75,8 +76,13 @@ static int stress_ptrace(const stress_args_t *args)
 
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
+again:
 	pid = fork();
 	if (pid < 0) {
+		if (stress_redo_fork(errno))
+			goto again;
+		if (!keep_stressing(args))
+			goto finish;
 		pr_fail("%s: fork failed, errno=%d (%s)\n",
 			args->name, errno, strerror(errno));
 		return EXIT_FAILURE;
@@ -135,6 +141,7 @@ static int stress_ptrace(const stress_args_t *args)
 	} else {
 		/* Parent to do the tracing */
 		int status;
+		int i = 0;
 
 		(void)setpgid(pid, g_pgrp);
 
@@ -179,6 +186,23 @@ static int stress_ptrace(const stress_args_t *args)
 			 */
 			if (stress_syscall_wait(args, pid))
 				break;
+
+			/* periodicially perform invalid ptrace calls */
+			if ((i & 0x1ff) == 0) {
+				const pid_t bad_pid = stress_get_unused_pid_racy(false);
+				int ret;
+
+				/* exercise invalid options */
+				ret = ptrace(~0L, pid, 0, PTRACE_O_TRACESYSGOOD);
+				(void)ret;
+
+				/* exercise invalid pid */
+				ret = ptrace(PTRACE_SETOPTIONS, bad_pid,
+					0, PTRACE_O_TRACESYSGOOD);
+				(void)ret;
+			}
+			i++;
+
 			inc_counter(args);
 		} while (keep_stressing(args));
 
@@ -188,6 +212,7 @@ static int stress_ptrace(const stress_args_t *args)
 			pr_fail("%s: waitpid failed, errno=%d (%s)\n",
 				args->name, errno, strerror(errno));
 	}
+finish:
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
 	return EXIT_SUCCESS;
