@@ -264,16 +264,111 @@ static int stress_set(const stress_args_t *args)
 		}
 #endif
 #if defined(HAVE_SETREGID)
+#if defined(HAVE_GETRESGID)
+		{
+			gid_t rgid = -1;
+			gid_t egid = -1;
+			gid_t sgid = -1;
+
+			ret = getresgid(&rgid, &egid, &sgid);
+			if (ret == 0) {
+				ret = setregid(rgid, egid);
+				(void)ret;
+				ret = setregid((gid_t)-1, egid);
+				(void)ret;
+				ret = setregid(rgid, (gid_t)-1);
+				(void)ret;
+
+				if (geteuid() != 0) {
+					ret = setregid((gid_t)-2, egid);
+					(void)ret;
+					ret = setregid(rgid, (gid_t)-2);
+					(void)ret;
+				}
+			}
+		}
+#endif
 		ret = setregid((gid_t)-1, (gid_t)-1);
 		(void)ret;
 #endif
 
 #if defined(HAVE_SETRESUID)
+#if defined(HAVE_GETRESUID)
+		{
+			uid_t ruid = -1;
+			uid_t euid = -1;
+			uid_t suid = -1;
+
+			ret = getresuid(&ruid, &euid, &suid);
+			if (ret == 0) {
+				ret = setresuid(ruid, euid, suid);
+				(void)ret;
+				ret = setresuid(ruid, euid, (uid_t)-1);
+				(void)ret;
+				ret = setresuid(ruid, (uid_t)-1, suid);
+				(void)ret;
+				ret = setresuid(ruid, (uid_t)-1, (uid_t)-1);
+				(void)ret;
+				ret = setresuid((uid_t)-1, euid, suid);
+				(void)ret;
+				ret = setresuid((uid_t)-1, euid, (uid_t)-1);
+				(void)ret;
+				ret = setresuid((uid_t)-1, (uid_t)-1, suid);
+				(void)ret;
+
+				if (geteuid() != 0) {
+					ret = setresuid((uid_t)-2, euid, suid);
+					(void)ret;
+					ret = setresuid(ruid, (uid_t)-2, suid);
+					(void)ret;
+					ret = setresuid(ruid, euid, (uid_t)-2);
+					(void)ret;
+				}
+				ret = setresuid(ruid, euid, suid);
+				(void)ret;
+			}
+		}
+#endif
 		ret = setresuid((uid_t)-1, (uid_t)-1, (uid_t)-1);
 		(void)ret;
 #endif
 
 #if defined(HAVE_SETRESGID)
+#if defined(HAVE_GETRESGID)
+		{
+			gid_t rgid = -1;
+			gid_t egid = -1;
+			gid_t sgid = -1;
+
+			ret = getresgid(&rgid, &egid, &sgid);
+			if (ret == 0) {
+				ret = setresgid(rgid, egid, sgid);
+				(void)ret;
+				ret = setresgid(rgid, egid, (gid_t)-1);
+				(void)ret;
+				ret = setresgid(rgid, (gid_t)-1, sgid);
+				(void)ret;
+				ret = setresgid(rgid, (gid_t)-1, (gid_t)-1);
+				(void)ret;
+				ret = setresgid((gid_t)-1, egid, sgid);
+				(void)ret;
+				ret = setresgid((gid_t)-1, egid, (gid_t)-1);
+				(void)ret;
+				ret = setresgid((gid_t)-1, (gid_t)-1, sgid);
+				(void)ret;
+				if (geteuid() != 0) {
+					ret = setresgid((gid_t)-2, egid, sgid);
+					(void)ret;
+					ret = setresgid(rgid, (gid_t)-2, sgid);
+					(void)ret;
+					ret = setresgid(rgid, egid, (gid_t)-2);
+					(void)ret;
+				}
+				ret = setresgid(rgid, egid, sgid);
+				(void)ret;
+			}
+		}
+#endif
 		ret = setresgid((gid_t)-1, (gid_t)-1, (gid_t)-1);
 		(void)ret;
 #endif
@@ -361,6 +456,7 @@ static int stress_set(const stress_args_t *args)
 
 				/* Exercise long name (-EINVAL) */
 				ret = setdomainname(name, sizeof(name));
+				(void)ret;
 
 				/* Set name back */
 				(void)ret;
