@@ -365,12 +365,15 @@ static int stress_shm(const stress_args_t *args)
 				args->name, errno, strerror(errno));
 			return EXIT_FAILURE;
 		}
-fork_again:
+again:
 		pid = fork();
 		if (pid < 0) {
-			/* Can't fork, retry? */
-			if (errno == EAGAIN)
-				goto fork_again;
+			if (stress_redo_fork(errno))
+				goto again;
+			if (!keep_stressing(args)) {
+				rc = EXIT_SUCCESS;
+				goto finish;
+			}
 			pr_err("%s: fork failed: errno=%d: (%s)\n",
 				args->name, errno, strerror(errno));
 			(void)close(pipefds[0]);
@@ -464,6 +467,7 @@ fork_again:
 			_exit(rc);
 		}
 	}
+finish:
 	if (orig_sz != sz)
 		pr_dbg("%s: reduced shared memory size from "
 			"%zu to %zu bytes\n", args->name, orig_sz, sz);
