@@ -104,12 +104,12 @@ static int stress_vforkmany(const stress_args_t *args)
 
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 fork_again:
-	if (!keep_stressing_flag())
-		goto tidy;
 	chpid = fork();
 	if (chpid < 0) {
-		if (errno == EAGAIN)
+		if (stress_redo_fork(errno))
 			goto fork_again;
+		if (!keep_stressing(args))
+			goto finish;
 		pr_err("%s: fork failed: errno=%d: (%s)\n",
 			args->name, errno, strerror(errno));
 		(void)munmap((void *)terminate_mmap, args->page_size);
@@ -275,7 +275,7 @@ STRESS_PRAGMA_POP
 			(void)kill(chpid, SIGKILL);
 		}
 	}
-tidy:
+finish:
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 
 	(void)munmap((void *)terminate_mmap, args->page_size);
