@@ -118,7 +118,7 @@ static const morse_t morse[] = {
 	{ ' ', " " }
 };
 
-static stress_zlib_rand_data_info_t zlib_rand_data_methods[];
+static const stress_zlib_rand_data_info_t zlib_rand_data_methods[];
 static volatile bool pipe_broken = false;
 static sigjmp_buf jmpbuf;
 
@@ -911,7 +911,7 @@ static HOT OPTIMIZE3 void stress_zlib_random_test(
 /*
  * Table of zlib data methods
  */
-static stress_zlib_rand_data_info_t zlib_rand_data_methods[] = {
+static const stress_zlib_rand_data_info_t zlib_rand_data_methods[] = {
 	{ "random",	stress_zlib_random_test }, /* Special "random" test */
 
 	{ "00ff",	stress_rand_data_00_ff },
@@ -974,7 +974,7 @@ static int stress_set_zlib_mem_level(const char *opt)
  */
 static int stress_set_zlib_method(const char *opt)
 {
-	stress_zlib_rand_data_info_t *info;
+	const stress_zlib_rand_data_info_t *info;
 
 	for (info = zlib_rand_data_methods; info->func; info++) {
 		if (!strcmp(info->name, opt)) {
@@ -1490,14 +1490,19 @@ static int stress_zlib(const stress_args_t *args)
 
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
+again:
 	pid = fork();
 	if (pid < 0) {
+		if (stress_redo_fork(errno))
+			goto again;
 		(void)close(fds[0]);
 		(void)close(fds[1]);
 		(void)close(deflate_xsum_fds[0]);
 		(void)close(deflate_xsum_fds[1]);
 		(void)close(inflate_xsum_fds[0]);
 		(void)close(inflate_xsum_fds[1]);
+		if (!keep_stressing(args))
+			return EXIT_SUCCESS;
 		pr_err("%s: fork failed, errno=%d (%s)\n",
 			args->name, errno, strerror(errno));
 		return EXIT_FAILURE;
